.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#create-specialized-uis'>
    </head>

# Create specialized UIs

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Build a sequential UI<pipeline/index>
Build custom components<custom_components/index>
```
